#
# spec file for package espeak-ng
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
Name:           espeak-ng
Version:        1.50
Release:        1.15
Summary:        Software speech synthesizer (text-to-speech)
License:        GPL-3.0-or-later AND BSD-2-Clause AND Apache-2.0 AND Unicode-DFS-2015
URL:            https://github.com/espeak-ng/espeak-ng
Source0:        https://github.com/espeak-ng/espeak-ng/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         espeak-ng-1.49.2-fix_no_return_nonvoid-in-configure.patch
# PATCH-FIX-UPSTREAM espeak-ng-1.50-fix_gcc10_no_common.patch
Patch2:         espeak-ng-1.50-fix_gcc10_no_common.patch
# PATCH-FIX_UPSTREAM espeak-ng-1.50-fix_gcc10_no_common_2.patch
Patch3:         espeak-ng-1.50-fix_gcc10_no_common_2.patch
BuildRequires:  fdupes
BuildRequires:  libtool >= 2.4.2
BuildRequires:  pcaudiolib-devel
BuildRequires:  pkgconfig

%description
The eSpeak NG (Next Generation) Text-to-Speech program is a speech
synthesizer that supports 100 languages and accents. It is based
on the eSpeak engine created by Jonathan Duddington. It uses
spectral formant synthesis by default which sounds robotic, but can
be configured to use Klatt formant synthesis or MBROLA to give it a
more natural sound.

%package        devel
Summary:        Development files for espeak-ng
Requires:       lib%{name}%{sover} = %{version}

%description    devel
This package contains development files for espeak-ng.

%package        compat
Summary:        Executables compatible with the original espeak
Requires:       %{name} = %{version}
Conflicts:      espeak

%description    compat
This package contains executables compatible with the original espeak.

%package        compat-devel
Summary:        Development files for espeak-ng compatible with espeak
Requires:       %{name}-compat = %{version}
Requires:       espeak-ng-devel = %{version}
Conflicts:      espeak-devel

%description    compat-devel
This package contains development files for espeak-ng
compatible with the original espeak.

%package     -n lib%{name}%{sover}
Summary:        Software speech synthesizer (text-to-speech)

%description -n lib%{name}%{sover}
Software speech synthesizer (text-to-speech), support
library.

%prep
%autosetup -p1
# let's have a versioned data dir
sed -i '/^DATADIR/s/data/data-%{version}/' Makefile.am
# remove spurious executable flag
chmod -x espeak-ng-data/lang/tai/shn

%build
./autogen.sh
%configure \
   --with-extdict-ru \
   --with-extdict-zh \
   --with-extdict-zhy
# build is not parallel-safe
make V=1

%install
%make_install
find %{buildroot} \( -name *.a -o -name *.la -o -name libespeak-ng-test* \) -delete
pushd %{buildroot}%{_libdir}
ln -s lib%{name}.so.%{sover} libespeak.so
popd
%fdupes %{buildroot}

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files
%doc CHANGELOG.md README.md
%license COPYING COPYING.APACHE COPYING.BSD2 COPYING.IEEE COPYING.UCD
%{_bindir}/espeak-ng
%{_bindir}/speak-ng
%{_datadir}/vim

%files devel
%exclude %{_includedir}/espeak
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files compat
%{_bindir}/espeak
%{_bindir}/speak

%files compat-devel
%{_includedir}/espeak
%{_libdir}/libespeak.so

%files -n lib%{name}%{sover}
%{_datadir}/espeak-ng-data-%{version}
%{_libdir}/lib%{name}.so.%{sover}*

%changelog
* Thu Jan  9 2020 aloisio@gmx.com
- Added espeak-ng-1.50-fix_gcc10_no_common.patch and
  espeak-ng-1.50-fix_gcc10_no_common_2.patch (fix boo#1160389)
* Fri Nov 29 2019 aloisio@gmx.com
- Update to version 1.50
  * Add a `--disable-rpath` option to prevent libtool hardcoding
    rpaths in the executable.
  * Renamed the `hy-arevmda` language to `hyw`, following the
    2018-03-30 change to the BCP 47 language subtag registry
    making the newly registered `hyw` language code the preferred
    value for `hy-arevmda`. This change keeps support for
    detecting the `hy-arevela` and `hy-arevmda` language tags.
  * Support any length replacement rule strings for the source
    part of the rule (replacing from the 'source' string to the
    'target' string).
  * Add more tests to check the various parts of espeak-ng.
  * Various changes to clean up the codebase.
  * Fix various compiler warnings (`-Winitialized`,
    `-Wmissing-prototypes`, `-Wreturn-type`, and `-Wunused`).
  security:
  * Fix several crashes in the emoji support.
  * Fix several static analysis issues detected by Coverity Scan.
  * Fix several static analysis issues detected by Microsoft
    Visual C++ `/analyze`.
  * `oss-fuzz` support for the SSML logic.
  * Fix running `make check` with `-fsanitize=address` (LLVM
    AddressSanitizer).
  documentation:
  * document the Kirshenbaum phoneme transcription scheme (used
    as the basis of espeak phonemes).
  * document the X-SAMPA phoneme transcription scheme.
  * document the Conlang X-SAMPA phoneme transcription scheme.
  emoji:
  * Update the emoji to Unicode 11.0.
  * Update the emoji translations to CLDR 33.1.
  * gd (Scottish Gaelic)
  * sd (Sindhi)
  * yue (Chinese (Cantonese))
  new languages:
  * ba (Bashkir) -- tc-dl, Valdis Vitolins
  * hak (Hakka Chinese) -- Chen Chien-ting
  * ht (Haitian Creole) -- Valdis Vitolins
  * kk (Kazakh) -- boracasli14, Valdis Vitolins
  * py (Pyash) -- Logan Streondj
  * quc (K'iche') -- Valdis Vitolins
  * ru-lv (Russian Latvia) -- Valdis Vitolins
  * shn (Shan Tay Yai) -- ronaldaug
  * uz (Uzbek) -- Valdis Vitolins
  updated languages:
  * af (Afrikaans) -- Christo de Klerk
  * ar (Arabic) -- Valdis Vitolins, Mark Readdie, Hesham Assabahi
  * cmn (Chinese Mandarin) -- materia-cccp
  * de (German) -- Reece Dunn, Karl Eick
  * en (English) -- Reece Dunn
  * fa (Farsi/Persian) -- Shadyar Khodayari
  * fi (Finnish) -- Juho Hiltunen
  * fr (French) -- Shallowmallow, Karl Eick, maiido, Reece Dunn
  * ku (Kurdish) -- rojanu
  * it (Italian) -- chrislm
  * lv (Latvian) -- Valdis Vitolins
  * my (Myanmar/Burmese) -- Min Maung
  * ru (Russian) -- Valdis Vitolins, Reece Dunn
  * sd (Sindhi) -- Ejaz Shah
  * ur (Urdu) -- Ejaz Shah
  * vi (Vietnamese) -- Anh Hoang Nguyen
- Dropped espeak-ng-1.49.2-fix_no_return_nonvoid.patch (no longer
  necessary)
* Fri Jul 12 2019 mliska@suse.cz
- Add espeak-ng-1.49.2-fix_no_return_nonvoid-in-configure.patch
  in order to fix missing return type in a function.
* Mon Mar  5 2018 aloisio@gmx.com
- Added link to match libespeak filename in the compat-devel
  package
* Mon Feb 26 2018 aloisio@gmx.com
- Added missing runtime dependency
* Wed Feb 21 2018 aloisio@gmx.com
- Added pcaudiolib build requirement
* Sat Feb 10 2018 aloisio@gmx.com
- Use a versioned datadir
* Fri Feb  9 2018 aloisio@gmx.com
- Split library into separate package
* Tue Jan 16 2018 aloisio@gmx.com
- Added Conflicts lines
* Tue Nov 28 2017 aloisio@gmx.com
- Initial package (1.49.2)
